@@ -24,5 +24,10 @@ class App(Base):
   def source(self, *args, **kwargs):
     return Base._source_common(self, Stream, *args, **kwargs)
 
+  def source_from_csv(self, *args, **kwargs):
+    return Base._source_from_csv_common(self, Stream, *args, **kwargs)
+
+
+
   def call_component(self, *args, **kwargs):
     return Base._call_component_common(self, None, Stream, *args, **kwargs)
